"""Module for working with Origin Destination Cost Matrix Solver."""

from enum import IntEnum
from arcgisscripting import na as cna  # pylint:disable=no-name-in-module

# List of names exported from this module
__all__ = ["OriginDestinationCostMatrixInputDataType", "OriginDestinationCostMatrixOutputDataType",
           "OriginDestinationCostMatrix"]


class OriginDestinationCostMatrixInputDataType(IntEnum):
    """Enumeration for feature class names used by the Origin Destination Cost Matrix solver to store inputs."""

    Origins = 0
    Destinations = 1
    PointBarriers = 2
    LineBarriers = 3
    PolygonBarriers = 4


class OriginDestinationCostMatrixOutputDataType(IntEnum):
    """Enumeration for feature class names used by the Origin Destination Cost Matrix solver to store outputs."""

    Origins = 0
    Destinations = 1
    Lines = 2


class OriginDestinationCostMatrix(cna.OriginDestinationCostMatrix):
    """Perform origin destination cost matrix analysis.

    # An example showing how to perform origin destination cost matrix analysis using inputs from feature classes.
    import arcpy
    import arcpy._na as nax

    nds = "C:/data/NorthAmerica.gdb/Routing/Routing_ND"
    nd_layer_name = "Routing_ND"
    input_origins = "C:/data/io.gdb/Origins"
    input_destinations = "C:/data/io.gdb/Destinations"
    output_lines = "C:/data/io.gdb/ODCostMatrixLines"

    arcpy.CheckOutExtension("network")
    arcpy.na.MakeNetworkDatasetLayer(nds, nd_layer_name)
    nd_travel_modes = arcpy.na.GetTravelModes(nd_layer_name)
    travel_mode = nd_travel_modes["Driving Time"]
    odcm = nax.OriginDestinationCostMatrix(nd_layer_name)
    odcm.travelMode = travel_mode
    odcm.defaultImpedanceCutoff = 15
    odcm.defaultDestinationCount = 5
    odcm.lineShapeType = nax.LineShapeType.NoLine
    odcm.load(nax.OriginDestinationCostMatrixInputDataType.Origins, input_origins)
    odcm.load(nax.OriginDestinationCostMatrixInputDataType.Destinations, input_destinations)
    result = odcm.solve()
    if result.solveSucceeded:
        result.export(nax.OriginDestinationCostMatrixOutputDataType.Lines, output_lines)
    else:
        print("Solved failed")
        print(result.solverMessages())

    """

    # Prevent adding unsupported attributes to class instances
    __slots__ = ()

    def __init__(self, in_network):
        """Create an origin destination cost matrix solver object based on the input network dataset.

        Args:
                in_network: A string representing the full catalog path to the network dataset or a network dataset
                            layer object or a string representing the name of a network dataset layer. For best
                            performance pass a network dataset layer object or a network dataset layer name.

        Returns:
                No value..

        Raises:
                ValueError if the in_network does not exist or cannot be opened.

        """
        super().__init__(in_network)
