# -*- coding: utf-8 -*-
#COPYRIGHT 2019 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""The GeoAnalytics Server toolbox contains a set of powerful tools for
performing spatial analysis on big data. GeoAnalytics Tools are
powered by your ArcGIS GeoAnalytics Server. ArcGIS GeoAnalytics Server
distributes the analysis between multiple server nodes. By using
distributed processing, you can process large datasets in less time."""
__all__ = ['AggregatePoints', 'AppendData', 'CalculateDensity',
           'CalculateField', 'ClipLayer', 'CopyToDataStore', 'CreateBuffers',
           'CreateSpaceTimeCube', 'DescribeDataset', 'DetectIncidents',
           'DissolveBoundaries', 'FindHotSpots', 'FindPointClusters',
           'FindSimilarLocations', 'Forest', 'GeneralizedLinearRegression',
           'JoinFeatures', 'MergeLayers', 'OverlayLayers', 'ReconstructTracks',
           'SummarizeAttributes', 'SummarizeWithin']
__alias__ = 'geoanalytics'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Analyze Patterns toolset
@gptooldoc('CalculateDensity_geoanalytics', None)
def CalculateDensity(input_layer=None, output_name=None, bin_type=None, bin_size=None, weight=None, neighborhood_size=None, fields=None, area_unit_scale_factor=None, time_step_interval=None, time_step_repeat=None, time_step_reference=None, data_store=None):
    """CalculateDensity_geoanalytics(input_layer, output_name, bin_type, bin_size, weight, neighborhood_size, {fields;fields...}, {area_unit_scale_factor}, {time_step_interval}, {time_step_repeat}, {time_step_reference}, {data_store})

        Calculates a magnitude-per-unit area from point features that fall
        within a neighborhood around each cell.

     INPUTS:
      input_layer (Feature Set):
          The points that will be used to calculate the density.
      output_name (String):
          The name of the output feature service.
      bin_type (String):
          Specifies the bin shape that will be used in analysis.

          * SQUARE-The bin shape will be square. This is the default.

          * HEXAGON-The bin shape will be hexagonal.
      bin_size (Linear Unit):
          The size of the bins used to aggregate input features. When generating
          bins for squares, the number and units specified determine the height
          and length of the square. For hexagons, the number and units specified
          determine the distance between parallel sides.
      weight (String):
          Specifies the weighting to be applied to the density function.

          * UNIFORM-A magnitude-per-area calculation in which each bin is
          equally weighted. This is the default.

          * KERNEL-A magnitude-per-area calculation with a smoothing algorithm
          applied (kernel) that weights bins closer to the points more heavily.
      neighborhood_size (Linear Unit):
          The search radius to be applied to density calculations.
      fields {Field}:
          One or more fields denoting population values for each feature. The
          population field is the count or quantity to be spread across the
          landscape to create a continuous surface.Values in the population
          field must be numeric. By default, the
          density of the count of input points will always be calculated.
      area_unit_scale_factor {String}:
          Specifies the area units of the output density values. The default
          unit is based on the units of the output spatial reference.

          * ACRES-Area in acres

          * HECTARES-Area in hectares

          * SQUARE_MILES-Area in square miles

          * SQUARE_KILOMETERS-Area in square kilometers

          * SQUARE_METERS-Area in square meters

          * SQUARE_FEET-Area in square feet

          * SQUARE_YARDS-Area in square yards
      time_step_interval {Time unit}:
          A value that specifies the duration of the time step. This option is
          only available if the input points are time enabled and represent an
          instant in time. Time stepping can only be applied if time is enabled
          on the input.
      time_step_repeat {Time unit}:
          A value that specifies how often the time-step interval occurs. This
          option is only available if the input points are time enabled and
          represent an instant in time.
      time_step_reference {Date}:
          A date that specifies the reference time with which to align the time
          steps. The default is January 1, 1970, at 12:00 a.m. This option is
          only available if the input points are time enabled and represent an
          instant in time.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateDensity_geoanalytics(*gp_fixargs((input_layer, output_name, bin_type, bin_size, weight, neighborhood_size, fields, area_unit_scale_factor, time_step_interval, time_step_repeat, time_step_reference, data_store), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateSpaceTimeCube_geoanalytics', None)
def CreateSpaceTimeCube(point_layer=None, output_name=None, distance_interval=None, time_step_interval=None, time_step_interval_alignment=None, reference_time=None, summary_fields=None):
    """CreateSpaceTimeCube_geoanalytics(point_layer, output_name, distance_interval, time_step_interval, {time_step_interval_alignment}, {reference_time}, {summary_fields;summary_fields...})

        Summarizes a set of points into a netCDF data structure by
        aggregating them into space-time bins. Within each bin, the points are
        counted, and specified attributes are aggregated. For all bin
        locations, the trend for counts and summary field values are
        evaluated.

     INPUTS:
      point_layer (Feature Set):
          The input point feature class that will be aggregated into space-time
          bins.
      output_name (String):
          The output netCDF data cube that will be created to contain counts
          and summaries of the input feature point data.
      distance_interval (Linear Unit):
          The distance that will determine the bin size. The size of the bins
          will be used to aggregate the point_layer. All
          points that fall within the same distance_interval and
          time_step_interval will be aggregated.
      time_step_interval (Time unit):
          The number of seconds,  minutes, hours, days, weeks, or years that
          will represent a single time step. All points within the same
          time_step_interval and distance_interval will be aggregated. Examples
          of valid entries for this parameter are 1 Weeks, 13 Days, or 1 Months.
      time_step_interval_alignment {String}:
          Specifies how aggregation will occur based on the Time Interval
          (time_step_interval in Python) parameter.

          * END_TIME-Time steps will align to the last time event and aggregate
          back in time.

          * START_TIME-Time steps will align to the first time event and
          aggregate forward in time.

          * REFERENCE_TIME-Time steps will align to a specified date or time. If
          all points in the input features have a time stamp larger than the
          specified reference time (or it falls exactly on the start time of the
          input features), the time-step interval will begin with that reference
          time and aggregate forward in time (as occurs with the Start time
          alignment). If all points in the input features have a time stamp
          smaller than the specified reference time (or it falls exactly on the
          end time of the input features), the time-step interval will end with
          that reference time and aggregate backward in time (as occurs with the
          End time alignment). If the specified reference time is in the middle
          of the time extent of the data, a time-step interval will be created
          ending with the reference time provided (as occurs with the End time
          alignment); additional intervals will be created both before and after
          the reference time until the full time extent of the data is covered.
      reference_time {Date}:
          The date or time that will be used to align the time-step intervals.
          For example, to bin the data weekly, Monday to Sunday, set a reference
          time of Sunday at midnight to ensure that bins break between Sunday
          and Monday at midnight.
      summary_fields {Value Table}:
          The numeric field containing attribute values that will be used to
          calculate the specified statistic when aggregating into a space time
          cube. Multiple statistic and field combinations can be specified. Null
          values are excluded from all statistical calculations.Available
          statistic types are the following:

          * Sum-Adds the total value for the specified field within each bin.

          * Mean-Calculates the average for the specified field within each bin.

          * Minimum-Finds the smallest value for all records of the specified
          field within each bin.

          * Maximum-Finds the largest value for all records of the specified
          field within each bin.

          * Standard deviation-Finds the standard deviation on values in the
          specified field within each bin.
          Available fill types are the following:

          * Zeros-Fills empty bins with zeros.

          * Spatial_Neighbors-Fills empty bins with the average value of spatial
          neighbors.

          * Space Time Neighbors-Fills empty bins with the average value of
          space-time neighbors.

          * Temporal Trend-Fills empty bins using an interpolated univariate
          spline algorithm.
          Null values present in any of the summary fields will result in those
          features being excluded from the analysis. If count of points in each
          bin is part of your analysis strategy, consider creating separate
          cubes, one for the count (without summary fields) and one for summary
          fields. If the set of null values is different for each summary field,
          consider creating a separate cube for each summary field."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateSpaceTimeCube_geoanalytics(*gp_fixargs((point_layer, output_name, distance_interval, time_step_interval, time_step_interval_alignment, reference_time, summary_fields), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FindHotSpots_geoanalytics', None)
def FindHotSpots(point_layer=None, output_name=None, bin_size=None, neighborhood_size=None, time_step_interval=None, time_step_alignment=None, time_step_reference=None, data_store=None):
    """FindHotSpots_geoanalytics(point_layer, output_name, {bin_size}, {neighborhood_size}, {time_step_interval}, {time_step_alignment}, {time_step_reference}, {data_store})

        Given a set of features, identifies statistically significant hot
        spots and cold spots using the Getis-Ord Gi* statistic.

     INPUTS:
      point_layer (Feature Set):
          The point feature class for which hot spot analysis will be performed.
      output_name (String):
          The name of the output layer with the z-score and p-value results.
      bin_size {Linear Unit}:
          The distance interval that represents the bin size and units into
          which the point_layer will be aggregated. The distance interval must
          be a linear unit.
      neighborhood_size {Linear Unit}:
          The spatial extent of the analysis neighborhood. This value
          determines which features are analyzed together to assess local
          clustering.
      time_step_interval {Time unit}:
          The interval that will be used for the time step. This parameter is
          only used if time is enabled for point_layer.
      time_step_alignment {String}:
          Specifies how time steps will be aligned. This parameter is only
          available if the input points are time enabled and represent an
          instant in time.

          * END_TIME-Time steps will align to the last time event and aggregate
          back in time.

          * START_TIME-Time steps will align to the first time event and
          aggregate forward in time. This is the default.

          * REFERENCE_TIME-Time steps will align to a specified date or time. If
          all points in the input features have a time stamp larger than the
          specified reference time (or it falls exactly on the start time of the
          input features), the time-step interval will begin with that reference
          time and aggregate forward in time (as occurs with the Start time
          alignment). If all points in the input features have a time stamp
          smaller than the specified reference time (or it falls exactly on the
          end time of the input features), the time-step interval will end with
          that reference time and aggregate backward in time (as occurs with the
          End time alignment). If the specified reference time is in the middle
          of the time extent of the data, a time-step interval will be created
          ending with the reference time provided (as occurs with the End time
          alignment); additional intervals will be created both before and after
          the reference time until the full time extent of the data is covered.
      time_step_reference {Date}:
          The time that will be used to align the time steps and time intervals.
          This parameter is only used if time is enabled for point_layer.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FindHotSpots_geoanalytics(*gp_fixargs((point_layer, output_name, bin_size, neighborhood_size, time_step_interval, time_step_alignment, time_step_reference, data_store), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FindPointClusters_geoanalytics', None)
def FindPointClusters(input_points=None, output_name=None, minimum_points=None, search_distance=None, data_store=None, clustering_method=None):
    """FindPointClusters_geoanalytics(input_points, output_name, minimum_points, {search_distance}, {data_store}, {clustering_method})

        Finds clusters of point features in surrounding noise based on their
        spatial distribution.

     INPUTS:
      input_points (Feature Set):
          The point feature class containing the point clusters.
      output_name (String):
          The name of the output feature service.
      minimum_points (Long):
          The minimum number of features to be considered to form a cluster.
      search_distance {Linear Unit}:
          The maximum distance to be considered.The Minimum Features per
          Cluster specified must be found within this
          distance for cluster membership. Individual clusters will be separated
          by at least this distance. If a feature is located further than this
          distance from the next closest feature in the cluster, it will not be
          included in the cluster.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store.
      clustering_method {String}:
          Specifies the method that will be used to define clusters.

          * DBSCAN-Uses a specified distance to separate dense clusters from
          sparser noise. DBSCAN is the fastest of the clustering methods but is
          only appropriate if there is a clear distance that works well to
          define all clusters that may be present. This results in clusters that
          have similar densities.

          * HDBSCAN-Uses varying distances to separate clusters of varying
          densities from sparser noise. HDBSCAN is the most data-driven of the
          clustering methods and requires the least user input."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FindPointClusters_geoanalytics(*gp_fixargs((input_points, output_name, minimum_points, search_distance, data_store, clustering_method), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('Forest_geoanalytics', None)
def Forest(prediction_type=None, in_features=None, output_trained_name=None, variable_predict=None, treat_variable_as_categorical=None, explanatory_variables=None, create_variable_importance_table=None, features_to_predict=None, explanatory_variable_matching=None, number_of_trees=None, minimum_leaf_size=None, maximum_tree_depth=None, sample_size=None, random_variables=None, percentage_for_validation=None, data_store=None):
    """Forest_geoanalytics(prediction_type, in_features, output_trained_name, variable_predict, {treat_variable_as_categorical}, {explanatory_variables;explanatory_variables...}, {create_variable_importance_table}, {features_to_predict}, {explanatory_variable_matching;explanatory_variable_matching...}, {number_of_trees}, {minimum_leaf_size}, {maximum_tree_depth}, {sample_size}, {random_variables}, {percentage_for_validation}, {data_store})

        Creates models and generates predictions using an adaptation of Leo
        Breiman's random forest algorithm, which is a supervised machine
        learning method. Predictions can be performed for both categorical
        variables (classification) and continuous variables (regression).
        Explanatory variables can take the form of fields in the attribute
        table of the training features. In addition to validation of model
        performance based on the training data, predictions can be made to
        features.

     INPUTS:
      prediction_type (String):
          Specifies the operation mode of the tool. The tool can be run to
          train a model to only assess performance, predict features, or create
          a prediction surface.

          * TRAIN-A model will be trained, but no predictions will be generated.
          Use this option to assess the accuracy of your model before generating
          predictions. This option will output model diagnostics in the messages
          window and a chart of variable importance. This is the default

          * TRAIN_AND_PREDICT-Predictions or classifications will be generated
          for features. Explanatory variables must be provided for both the
          training features and the features to be predicted. The output of this
          option will be a feature class, model diagnostics in the messages
          window, and an optional table of variable importance.
      in_features (Record Set):
          The feature class containing the variable_predict parameter and the
          explanatory training variables fields.
      output_trained_name (String):
          The output feature layer name.
      variable_predict (Field):
          The variable from the in_features parameter containing the values to
          be used to train the model. This field contains known (training)
          values of the variable that will be used to predict at unknown
          locations.
      treat_variable_as_categorical {Boolean}:
          * CATEGORICAL-variable_predict is a categorical variable and the tool
          will perform classification.

          * NUMERIC-variable_predict is continuous and the tool will perform
          regression. This is the default.
      explanatory_variables {Value Table}:
          A list of fields representing the explanatory variables that help
          predict the value or category of variable_predict. Use the
          treat_variable_as_categorical parameter for any variables that
          represent classes or categories (such as land cover or presence or
          absence). Specify the variable as true for any that represent classes
          or categories such as land cover or presence or absence and false if
          the variable is continuous.
      create_variable_importance_table {Boolean}:
          If specified, the table will contain information describing the
          importance of each explanatory variable used in the model created.
      features_to_predict {Record Set}:
          A feature layer representing locations where predictions will be
          made. This feature layer must also contain any explanatory variables
          provided as fields that correspond to those used from the training
          data.
      explanatory_variable_matching {Value Table}:
          A list of explanatory_variables specified from in_features on the
          right and their corresponding fields from features_to_predict on the
          left, for example, [["LandCover2000", "LandCover2010"], ["Income",
          "PerCapitaIncome"]].
      number_of_trees {Long}:
          The number of trees to create in the forest model. More trees will
          generally result in more accurate model prediction, but the model will
          take longer to calculate. The default number of trees is 100.
      minimum_leaf_size {Long}:
          The minimum number of observations required to keep a leaf (that is,
          the terminal node on a tree without further splits).  The default
          minimum for regression is 5, and the default for classification is 1.
          For very large data, increasing these numbers will decrease the run
          time of the tool.
      maximum_tree_depth {Long}:
          The maximum number of splits that will be made down a tree. Using a
          large maximum depth, more splits will be created, which may increase
          the chances of overfitting the model. The default is data driven and
          depends on the number of trees created and the number of variables
          included.
      sample_size {Long}:
          The percentage of in_features used for each decision tree. The default
          is 100 percent of the data. Samples for each tree are taken randomly
          from two-thirds of the data specified. Each decision tree in the
          forest is created using a random sample or
          subset (approximately two-thirds) of the training data available.
          Using a lower percentage of the input data for each decision tree
          increases the speed of the tool for very large datasets.
      random_variables {Long}:
          The number of explanatory variables used to create each decision
          tree.Each decision tree in the forest is created using a random subset
          of
          the explanatory variables specified. Increasing the number of
          variables used in each decision tree will increase the chances of
          overfitting your model, particularly if there is one or more dominant
          variables. A common practice is to use the square root of the total
          number of explanatory variables if variable_predict is numeric, or
          divide the total number of explanatory variables by 3 if
          variable_predict is categorical.
      percentage_for_validation {Long}:
          The percentage (between 10 percent and 50 percent) of in_features to
          reserve as the test dataset for validation. The model will be trained
          without this random subset of data, and the observed values for those
          features will be compared to the predicted value. The default is 10
          percent.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.Forest_geoanalytics(*gp_fixargs((prediction_type, in_features, output_trained_name, variable_predict, treat_variable_as_categorical, explanatory_variables, create_variable_importance_table, features_to_predict, explanatory_variable_matching, number_of_trees, minimum_leaf_size, maximum_tree_depth, sample_size, random_variables, percentage_for_validation, data_store), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GeneralizedLinearRegression_geoanalytics', None)
def GeneralizedLinearRegression(input_features=None, dependent_variable=None, model_type=None, explanatory_variables=None, output_features_name=None, generate_coefficient_table=None, input_features_to_predict=None, explanatory_variables_to_match=None, dependent_variable_mapping=None, data_store=None):
    """GeneralizedLinearRegression_geoanalytics(input_features, dependent_variable, model_type, explanatory_variables;explanatory_variables..., output_features_name, {generate_coefficient_table}, {input_features_to_predict}, {explanatory_variables_to_match;explanatory_variables_to_match...}, {dependent_variable_mapping;dependent_variable_mapping...}, {data_store})

        Performs generalized linear regression (GLR) to generate predictions
        or to model a dependent variable in terms of its relationship to a set
        of explanatory variables. This tool can be used to fit continuous
        (OLS), binary (logistic), and count (Poisson) models.

     INPUTS:
      input_features (Record Set):
          The layer containing the dependent and independent variables.
      dependent_variable (Field):
          The numeric field containing the observed values to be modeled.
      model_type (String):
          Specifies the type of data that will be modeled.

          * CONTINUOUS-The dependent_variable is continuous. The Gaussian model
          will be used, and the tool will perform ordinary least squares
          regression.

          * BINARY-The dependent_variable represents presence or absence. This
          can be either conventional 1s and 0s, or string values mapped to 0 or
          1s in the Match Explanatory Variables parameter. The Logistic
          Regression model will be used.

          * COUNT-The dependent_variable is discrete and represents events, for
          example, crime counts,  disease incidents, or traffic accidents. The
          Poisson regression model will be used.
      explanatory_variables (Field):
          A list of fields representing independent explanatory variables in the
          regression model.
      output_features_name (String):
          The name of the feature class that will be created containing the
          dependent variable estimates and residuals.
      generate_coefficient_table {Boolean}:
          Specifies whether an output table with Boolean values will be
          generated.

          * CREATE_TABLE-A table with coefficient values will be generated.

          * NO_TABLE-A table with coefficient values will not be generated. This
          is the default.
      input_features_to_predict {Record Set}:
          A layer containing features representing locations where estimates
          should be computed. Each feature in this dataset should contain values
          for all the explanatory variables specified. The dependent variable
          for these features will be estimated using the model calibrated for
          the input layer data.
      explanatory_variables_to_match {Value Table}:
          Matches the explanatory variables in the input_features_to_predict
          parameter to corresponding explanatory variables from the
          input_features parameter-for example, [["LandCover2000",
          "LandCover2010"], ["Income", "PerCapitaIncome"]]
      dependent_variable_mapping {Value Table}:
          Two strings representing the values used to map to 0 (absence) and 1
          (presence) for binary regression. By default 0 and 1 will be used. For
          example, if you wanted to predict an arrest and had fields with values
          of Arrest and No Arrest, you would enter No Arrest for False Value (0)
          and Arrest for True Value (1).
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GeneralizedLinearRegression_geoanalytics(*gp_fixargs((input_features, dependent_variable, model_type, explanatory_variables, output_features_name, generate_coefficient_table, input_features_to_predict, explanatory_variables_to_match, dependent_variable_mapping, data_store), True)))
        return retval
    except Exception as e:
        raise e


# Find Locations toolset
@gptooldoc('DetectIncidents_geoanalytics', None)
def DetectIncidents(input_layer=None, output_name=None, track_fields=None, start_condition=None, end_condition=None, output_mode=None, data_store=None, time_boundary_split=None, time_boundary_reference=None):
    """DetectIncidents_geoanalytics(input_layer, output_name, track_fields;track_fields..., start_condition, {end_condition}, {output_mode}, {data_store}, {time_boundary_split}, {time_boundary_reference})

        Creates a new layer that detects features that meet a given condition.

     INPUTS:
      input_layer (Record Set):
          The input features that contain potential incidents.
      output_name (String):
          The name of the output feature service.
      track_fields (Field):
          A field or fields used to identify unique tracks.
      start_condition (Calculator Expression):
          The condition used to identify incidents. Expressions are written in
          Arcade and can include [+ - * / ] operators and multiple fields.
      end_condition {Calculator Expression}:
          The condition used to end incidents. If no end condition is specified,
          incidents will end when the start condition is no longer true.
      output_mode {String}:
          Specifies the features to return.

          * ALL_FEATURES-All the input features are returned. This is the
          default.

          * INCIDENTS-Only features that were found to be incidents are
          returned.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store.
      time_boundary_split {Time unit}:
          A time span to split your input data into for analysis. A time
          boundary allows your to analyze values within a defined time span. For
          example, if you use a time boundary of 1 day, starting on January 1,
          1980 tracks will be will be split at the beginning of every day. This
          parameter is only available with ArcGIS Enterprise 10.7 and later.
      time_boundary_reference {Date}:
          The reference time used to split your input data into for analysis.
          Time boundaries will be created for the whole span of the data, and
          the reference time does not need to occur at the start. If no
          reference time is used, January 1, 1970 is used. This parameter is
          only available with ArcGIS Enterprise 10.7 and later."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DetectIncidents_geoanalytics(*gp_fixargs((input_layer, output_name, track_fields, start_condition, end_condition, output_mode, data_store, time_boundary_split, time_boundary_reference), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FindSimilarLocations_geoanalytics', None)
def FindSimilarLocations(input_layer=None, search_layer=None, output_name=None, analysis_fields=None, most_or_least_similar=None, match_method=None, number_of_results=None, append_fields=None, data_store=None):
    """FindSimilarLocations_geoanalytics(input_layer, search_layer, output_name, analysis_fields;analysis_fields..., {most_or_least_similar}, {match_method}, {number_of_results}, {append_fields;append_fields...}, {data_store})

        Identifies the candidate features that are most similar or dissimilar
        to one or more input features based on feature attributes.

     INPUTS:
      input_layer (Record Set):
          The reference layer (or a selection on a layer) containing the
          features to be matched. The tool searches for other features similar
          to these features. When more than one feature is provided, matching is
          based on attribute averages.
      search_layer (Record Set):
          The candidate layer (or a selection on a layer) containing candidate-
          matching features. The tool searches for features most similar (or
          dissimilar) to the input_layer parameter among these candidates.
      output_name (String):
          The name of the output feature service. The output feature service
          contains a record for each of the input_layer parameters and for all
          the solution-matching features found.
      analysis_fields (String):
          A list of numeric attributes representing the matching criteria.
      most_or_least_similar {String}:
          Specifies whether the features to be found are most similar or least
          similar to the input_layer parameter.

          * MOST_SIMILAR-Finds the features that are most similar.

          * LEAST_SIMILAR-Finds the features that are least similar.

          * BOTH-Finds the features that are most similar and the features that
          are least similar.
      match_method {String}:
          Specifies whether matches will be based on values or cosine
          relationships.

          * ATTRIBUTE_VALUES-Similarity or dissimilarity will be based on the
          sum of squared standardized attribute value differences for all the
          analysis_fields attributes.

          * ATTRIBUTE_PROFILES-Similarity or dissimilarity will be computed as a
          function of cosine similarity for all the analysis_fields attributes.
      number_of_results {Long}:
          The number of solution matches to be found. Entering zero or a number
          larger than the total number of  search_layer features will return
          rankings for all the candidate features, with a maximum of 10,000.
      append_fields {Field}:
          An optional list of attributes to include with the output. You can
          include a name identifier, categorical field, or date field for
          example. These fields are not used to determine similarity; they are
          only included in the output parameter attributes for your reference.
          By default, all fields are added.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FindSimilarLocations_geoanalytics(*gp_fixargs((input_layer, search_layer, output_name, analysis_fields, most_or_least_similar, match_method, number_of_results, append_fields, data_store), True)))
        return retval
    except Exception as e:
        raise e


# Manage Data toolset
@gptooldoc('AppendData_geoanalytics', None)
def AppendData(input_layer=None, append_layer=None, append_method=None, append_fields=None, append_expressions=None):
    """AppendData_geoanalytics(input_layer, append_layer, append_method, {append_fields;append_fields...}, {append_expressions;append_expressions...})

        Appends features to an existing hosted feature layer.

     INPUTS:
      input_layer (Record Set):
          The hosted feature layer to which features will be appended.
      append_layer (Record Set):
          The layer containing features to append to the input layer.
      append_method (String):
          Specifies how fields from the Input Layer will be appended with
          values from the Append Layer.

          * MATCHING_ONLY-Input layer fields will only be appended if they have
          a matching field in the append layer. Fields without a match will be
          appended with null values.

          * FIELD_MAPPING-Input layer fields can be appended with append layer
          fields of the same name and different type, or with values calculated
          from Arcade expressions.
      append_fields {Value Table}:
          The append layer fields of the same type and different name as the
          input layer fields to be appended. Select the Input Field you want to
          append to, and the Append Field containing the values you want to
          append.
      append_expressions {Value Table}:
          The Arcade expression used to calculate field values for the input
          field. Expressions are written in Arcade and can include mathematical
          operators and multiple fields."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AppendData_geoanalytics(*gp_fixargs((input_layer, append_layer, append_method, append_fields, append_expressions), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CalculateField_geoanalytics', None)
def CalculateField(input_layer=None, output_name=None, field_name=None, field_type=None, expression=None, track_aware=None, track_fields=None, data_store=None, time_boundary_split=None, time_boundary_reference=None):
    """CalculateField_geoanalytics(input_layer, output_name, field_name, field_type, expression, {track_aware}, {track_fields;track_fields...}, {data_store}, {time_boundary_split}, {time_boundary_reference})

        Creates a layer with calculated field values.

     INPUTS:
      input_layer (Record Set):
          The input features that will have a field calculated.
      output_name (String):
          The name of the output feature service.
      field_name (String):
          The name of the field that will have values calculated. This can be
          an existing field or a new field name.
      field_type (String):
          Specifies the field type for the calculated field.

          * STRING-The new field will be of type text.

          * INTEGER-The new field will be of type integer.

          * FLOAT-The new field will be of type float.

          * DATE-The new field will be of type date.
      expression (Calculator Expression):
          Calculates values in the field. Expressions are written in Arcade and
          can include operators and multiple fields. Calculated values are
          applied in the units of the spatial reference of the input, unless a
          geographic coordinate system is used, in which case they will be in
          meters.
      track_aware {Boolean}:
          Specifies whether the expression uses a track-aware expression.

          * TRACK_AWARE-The expression uses a track-aware expression, and a
          track field must be specified.

          * NOT_TRACK_AWARE-The expression does not use a track-aware
          expression. This is the default.
      track_fields {Field}:
          One or more fields used to identify unique tracks.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store.
      time_boundary_split {Time unit}:
          A time span to split your input data into for analysis. A time
          boundary allows your to analyze values within a defined time span. For
          example, if you use a time boundary of 1 day, starting on January 1,
          1980 tracks will be will be split at the beginning of every day. This
          parameter is only available with ArcGIS Enterprise 10.7 and later.
      time_boundary_reference {Date}:
          The reference time used to split your input data into for analysis.
          Time boundaries will be created for the whole span of the data, and
          the reference time does not need to occur at the start. If no
          reference time is used, January 1, 1970 is used. This parameter is
          only available with ArcGIS Enterprise 10.7 and later."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateField_geoanalytics(*gp_fixargs((input_layer, output_name, field_name, field_type, expression, track_aware, track_fields, data_store, time_boundary_split, time_boundary_reference), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ClipLayer_geoanalytics', None)
def ClipLayer(input_layer=None, clip_layer=None, output_name=None, data_store=None):
    """ClipLayer_geoanalytics(input_layer, clip_layer, output_name, {data_store})

        Extracts input features from within specified polygons.

     INPUTS:
      input_layer (Feature Set):
          The dataset containing the point, line, or polygon features to be
          clipped.
      clip_layer (Feature Set):
          The dataset containing the polygon features used to clip the input
          features.
      output_name (String):
          The name of the output feature service.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ClipLayer_geoanalytics(*gp_fixargs((input_layer, clip_layer, output_name, data_store), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CopyToDataStore_geoanalytics', None)
def CopyToDataStore(input_layer=None, output_name=None, data_store=None):
    """CopyToDataStore_geoanalytics(input_layer, output_name, {data_store})

        Copies features from the input to a new feature service in your
        portal.

     INPUTS:
      input_layer (Record Set):
          The features to be copied.
      output_name (String):
          Name of output feature service.
      data_store {String}:
          The ArcGIS Data Store to which the output will be saved. The default
          is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in your
          spatiotemporal big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in your relational data
          store."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CopyToDataStore_geoanalytics(*gp_fixargs((input_layer, output_name, data_store), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DissolveBoundaries_geoanalytics', None)
def DissolveBoundaries(input_layer=None, output_name=None, multipart=None, dissolve_fields=None, fields=None, summary_fields=None, data_store=None):
    """DissolveBoundaries_geoanalytics(input_layer, output_name, {multipart}, {dissolve_fields}, {fields;fields...}, {summary_fields;summary_fields...}, {data_store})

        Finds polygons that intersect or have the same field values and merges
        them to form a single polygon.Which boundaries are merged can be
        controlled by specifying one or
        more fields. For example, if you have a layer of counties and each
        county has a State_Name field, you can dissolve boundaries using the
        State_Name field. Adjacent counties will be merged if they have the
        same value for State_Name. The result is a layer of state boundaries.

     INPUTS:
      input_layer (Feature Set):
          The layer containing the polygon features that will be dissolved.
      output_name (String):
          The name of the output feature service.
      multipart {Boolean}:
          Specifies whether multipart features will be created in the output
          feature class.

          * MULTI_PART-Multipart features will be created.

          * SINGLE_PART-Multipart features will not be created. Individual
          features will be created for each part instead. This is the default.
      dissolve_fields {Boolean}:
          Specifies whether features with the same field values will be
          dissolved.

          * NO_DISSOLVE_FIELDS-Polygons that share a common border (that is,
          they are adjacent) or polygons that overlap will be dissolved into one
          polygon. This is the default.

          * DISSOLVE_FIELDS-Polygons that have the same field value or values
          will be dissolved.
      fields {Field}:
          The field or fields that will be used to dissolve like features.
          Features with the same value for each field will be dissolved.
      summary_fields {Value Table}:
          The statistics that will be calculated on specified fields.

          * Count-Calculates the number of nonnull values. It can be used on
          numeric fields or strings. The count of [null, 0, 2] is 2.

          * Sum-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * Mean-The mean of numeric values. The mean of [0,2, null] is 1.

          * Min-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * Max-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * Standard Deviation-The standard deviation of a numeric field. The
          standard deviation of [1] is null. The standard deviation of [null,
          1,1,1] is 1.

          * Variance-The variance of a numeric field in a track. The variance of
          [1] is null. The variance of [null, 1,1,1] is 1.

          * Range-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * Any-A sample string from a field of type string.
           The statistics that will be calculated on specified fields.

          * COUNT-Calculates the number of nonnull values. It can be used on
          numeric fields or strings. The count of [null, 0, 2] is 2.

          * SUM-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * MEAN-The mean of numeric values. The mean of [0,2, null] is 1.

          * MIN-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * MAX-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * STDDEV-The standard deviation of a numeric field. The standard
          deviation of [1] is null. The standard deviation of [null, 1,1,1] is
          1.

          * VAR-The variance of a numeric field in a track. The variance of [1]
          is null. The variance of [null, 1,1,1] is 1.

          * RANGE-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * ANY-A sample string from a field of type string.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DissolveBoundaries_geoanalytics(*gp_fixargs((input_layer, output_name, multipart, dissolve_fields, fields, summary_fields, data_store), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('MergeLayers_geoanalytics', None)
def MergeLayers(input_layer=None, merge_layer=None, output_name=None, merging_attributes=None, data_store=None):
    """MergeLayers_geoanalytics(input_layer, merge_layer, output_name, {merging_attributes;merging_attributes...}, {data_store})

        Combines feature layers to create a single output layer.The tool
        requires that both inputs have the same geometry type (point,
        line, or polygon) or be tables. If time is enabled on one layer, the
        other layer must also be time enabled and have the same time type
        (instant or interval). The result will always contain all fields from
        the input layer. All fields from the merge layer will be included by
        default, or you can specify custom merge rules to define the resulting
        schema. The following are examples:

        * You have three layers representing the administrative boundaries of
        England, Wales, and Scotland and want a single layer of Great Britain.
        You can use Merge Layers to combine the areas and maintain all fields
        from each area.

        * You have two layers containing parcel information for contiguous
        townships. You want to merge them into a single layer, keeping only
        the fields that have the same name and type in the two layers.

     INPUTS:
      input_layer (Record Set):
          The point, line, or polygon features or table to merge with the merge
          layer.
      merge_layer (Record Set):
          The point, line, or polygon features or table to merge with the input
          layer. The merge layer must contain the same feature type and time
          type as the input layer.
      output_name (String):
          The name of the output feature service.
      merging_attributes {Value Table}:
          A list of values that describe how fields from the merge layer are to
          be modified and matched with fields in the input layer. All fields
          from the input layer will be written to the output layer. If no
          merging attributes are defined, all fields from the merge layer will
          be written to the output layer.If a field exists in one layer but not
          the other, the output layer
          will still contain two fields. The output field will contain null
          values for the input features that did not have the field. For
          example, if the input layer contains a field named TYPE but the merge
          layer does not contain TYPE, the output will contain TYPE, but its
          values will be null for all the features copied from the merge
          layer.You can control how fields in the merge layer are written to the
          output layer using the following merge types:

          * Remove-The merge layer field will be removed from the output layer.

          * Rename-The merge layer field will be renamed in the output. You
          cannot rename a field from the merge layer to a field from the input
          layer. To make field names equivalent, use the match option.

          * Match-The merge layer field is renamed and matched to a field from
          the input layer. For example, the input layer has a field named CODE
          and the merge layer has a field named STATUS. You can match STATUS to
          CODE, and the output will contain the CODE field with values of the
          STATUS field used for features copied from the merge layer. Type
          casting is supported for numeric values. Matching numeric fields to
          string fields is not supported.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MergeLayers_geoanalytics(*gp_fixargs((input_layer, merge_layer, output_name, merging_attributes, data_store), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('OverlayLayers_geoanalytics', None)
def OverlayLayers(input_layer=None, overlay_layer=None, output_name=None, overlay_type=None, include_overlaps=None, data_store=None):
    """OverlayLayers_geoanalytics(input_layer, overlay_layer, output_name, overlay_type, {include_overlaps}, {data_store})

        Overlays the geometries from multiple layers into a single layer.
        Overlay can be used to combine, erase, modify, or update spatial
        features.Overlay is used to answer one of the most basic questions of
        geography, What is on top of what? The following are examples:

        * What parcels are within the 100-year floodplain? (Within is another
        way of saying on top of.)

        * What land use is on top of what soil type?

        * What mines are within abandoned military bases?

     INPUTS:
      input_layer (Feature Set):
          The point, line, or polygon features that will be overlaid with the
          overlay layer.
      overlay_layer (Feature Set):
          The features that will be overlaid with the input layer features.
      output_name (String):
          The name of the output feature service.
      overlay_type (String):
          Specifies the type of overlay to be performed.

          * INTERSECT-Computes a geometric intersection of the input layers.
          Features or portions of features that overlap in both the input layer
          and overlay layer will be written to the output layer. This is the
          default.

          * ERASE-Only those features or portions of features in the overlay
          layer that are not within the features in the input layer are written
          to the output.

          * UNION-Computes a geometric union of the input layer and overlay
          layer. All features and their attributes will be written to the layer.

          * IDENTITY-Computes a geometric intersection of the input features
          and identity features. Features or portions of features that overlap
          in both input layer and overlay layer will be written to the output
          layer.

          * SYMMETRICAL_DIFFERENCE-Features or portions of features in the
          input layer and overlay layer that do not overlap will be written to
          the output layer.
      include_overlaps {Boolean}:
          Specifies whether one or both of the input layers have overlapping
          features.

          * OVERLAPPING-One or both of the layers have overlapping features.
          This is the default.

          * NOT_OVERLAPPING-Neither layer has overlapping features.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.OverlayLayers_geoanalytics(*gp_fixargs((input_layer, overlay_layer, output_name, overlay_type, include_overlaps, data_store), True)))
        return retval
    except Exception as e:
        raise e


# Summarize Data toolset
@gptooldoc('AggregatePoints_geoanalytics', None)
def AggregatePoints(point_layer=None, output_name=None, polygon_or_bin=None, polygon_layer=None, bin_type=None, bin_size=None, time_step_interval=None, time_step_repeat=None, time_step_reference=None, summary_fields=None, data_store=None):
    """AggregatePoints_geoanalytics(point_layer, output_name, polygon_or_bin, {polygon_layer}, {bin_type}, {bin_size}, {time_step_interval}, {time_step_repeat}, {time_step_reference}, {summary_fields;summary_fields...}, {data_store})

        Aggregates points into polygon features or bins. A polygon is
        returned with a count of points as well as optional statistics at all
        locations where points exist.

     INPUTS:
      point_layer (Feature Set):
          The point features to be aggregated into polygons or bins.
      output_name (String):
          The name of the output feature service.
      polygon_or_bin (String):
          Specifies how the point_layer will be aggregated.

          * POLYGONS-The point layer will be aggregated into a polygon dataset.

          * BINS-The point layer will be aggregated into square or hexagonal
          bins that are generated when the tool is run.
      polygon_layer {Feature Set}:
          The polygon features into which the input points will be aggregated.
      bin_type {String}:
          Specifies the bin shape that will be generated to hold the aggregated
          points.

          * SQUARE-Square bins in which the bin_size represents the height of a
          square. This is the default.

          * HEXAGON-Hexagonal bins in which the bin_size represents the height
          between two parallel sides.
      bin_size {Linear Unit}:
          The distance interval that represents the bin size and units into
          which the point_layer will be aggregated. The distance interval must
          be a linear unit.
      time_step_interval {Time unit}:
          A value that specifies the duration of the time step. This option is
          only available if the input points are time enabled and represent an
          instant in time. Time stepping can only be applied if time is enabled
          on the input.
      time_step_repeat {Time unit}:
          A value that specifies how often the time-step interval occurs. This
          option is only available if the input points are time enabled and
          represent an instant in time.
      time_step_reference {Date}:
          A date that specifies the reference time with which to align the time
          steps. The default is January 1, 1970, at 12:00 a.m. This option is
          only available if the input points are time enabled and represent an
          instant in time.
      summary_fields {Value Table}:
          The statistics that will be calculated on specified fields.

          * COUNT-Calculates the number of nonnull values. It can be used on
          numeric fields or strings. The count of [null, 0, 2] is 2.

          * SUM-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * MEAN-The mean of numeric values. The mean of [0,2, null] is 1.

          * MIN-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * MAX-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * STDDEV-The standard deviation of a numeric field. The standard
          deviation of [1] is null. The standard deviation of [null, 1,1,1] is
          1.

          * VAR-The variance of a numeric field in a track. The variance of [1]
          is null. The variance of [null, 1,1,1] is 1.

          * RANGE-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * ANY-A sample string from a field of type string.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AggregatePoints_geoanalytics(*gp_fixargs((point_layer, output_name, polygon_or_bin, polygon_layer, bin_type, bin_size, time_step_interval, time_step_repeat, time_step_reference, summary_fields, data_store), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DescribeDataset_geoanalytics', None)
def DescribeDataset(input_layer=None, output_name=None, sample_features=None, create_extent_layer=None, data_store=None):
    """DescribeDataset_geoanalytics(input_layer, output_name, {sample_features}, {create_extent_layer}, {data_store})

        Summarizes features into calculated field statistics, sample features,
        and extent boundaries.

     INPUTS:
      input_layer (Record Set):
          The point, line, polygon, or tabular features to be described.
      output_name (String):
          The name of the output feature service.
      sample_features {Long}:
          The number of features that will be included in the output sample
          layer. No sample is returned when you select 0 features or don't
          provide a number. This is the default.
      create_extent_layer {Boolean}:
          Specifies whether an output extent layer will be created. The extent
          is a polygon that represents the spatial and temporal extent of the
          input features.

          * CREATE_EXTENT-An extent layer will be created.

          * NO_EXTENT-An extent layer will not be created.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DescribeDataset_geoanalytics(*gp_fixargs((input_layer, output_name, sample_features, create_extent_layer, data_store), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('JoinFeatures_geoanalytics', None)
def JoinFeatures(target_layer=None, join_layer=None, output_name=None, join_operation=None, spatial_relationship=None, spatial_near_distance=None, temporal_relationship=None, temporal_near_distance=None, attribute_relationship=None, summary_fields=None, join_condition=None, data_store=None):
    """JoinFeatures_geoanalytics(target_layer, join_layer, output_name, join_operation, {spatial_relationship}, {spatial_near_distance}, {temporal_relationship}, {temporal_near_distance}, {attribute_relationship;attribute_relationship...}, {summary_fields;summary_fields...}, {join_condition}, {data_store})

        Joins attributes from one layer to another based on spatial, temporal,
        or attribute relationships, or a combination of those relationships.

     INPUTS:
      target_layer (Record Set):
          Contains the target features. The attributes from the target features
          and the attributes from the joined features are transferred to the
          output.
      join_layer (Record Set):
          Contains the join features. The attributes from the join features are
          joined to the attributes of the target features. See the explanation
          of the Join Operation (join_operation in Python) parameter for details
          about how the aggregation of joined attributes are affected by the
          type of join operation.
      output_name (String):
          The name of the output feature service.
      join_operation (String):
          Specifies how joins between the target_layer and join_layer will be
          handled in the output feature if multiple join features are found that
          have the same spatial relationship with a single target feature.

          * JOIN_ONE_TO_ONE-The attributes from the multiple join features will
          be aggregated. For example, if a point target feature is found within
          two separate polygon join features, the attributes from the two
          polygons will be aggregated before being transferred to the output
          point feature class. If one polygon has an attribute value of 3 and
          the other has a value of 7, and the summary statistic sum is specified
          for that field, the aggregated value in the output feature class will
          be 10. This is the default, and only the count statistic is returned.

          * JOIN_ONE_TO_MANY-The output feature class will contain multiple
          copies (records) of the target feature. For example, if a single-point
          target feature is found within two separate polygon join features, the
          output feature class will contain two copies of the target feature:
          one record with the attributes of one polygon and another record with
          the attributes of the other polygon. There are no summary statistics
          available with this method.
      spatial_relationship {String}:
          Defines the criteria used to spatially join features.

          * INTERSECTS-The features in the join features will be matched if they
          intersect a target feature. This is the default.

          * EQUALS-The features in the join features will be matched if they
          are the same geometry as a target feature.

          * NEAR-The features in the join features will be matched if they are
          within a specified distance of a target feature. The distance is
          measured using planar distance. Specify a distance in the
          spatial_near_distance parameter.

          * NEAR_GEODESIC-The features in the join features will be matched if
          they are within a specified distance of a target feature. The distance
          is measured geodesically. Specify a distance in the
          spatial_near_distance parameter. This option is available with ArcGIS
          Enterprise 10.7 or later.

          * CONTAINS-The features in the join features will be matched if a
          target feature contains them. The target features must be polygons or
          polylines. The join features can only be polygons when the target
          features are also polygons. Polygon can contain any feature type.
          Polyline can contain only polyline and point. Point cannot contain any
          feature, not even a point. If the join feature is entirely on the
          boundary of the target feature (no part is properly inside or
          outside), the feature will not be matched.

          * WITHIN-The features in the join features will be matched if a target
          feature is within them. It is the opposite of the contains
          relationship. For this option, the target features can only be
          polygons when the join features are also polygons. Point can be a join
          feature only if point is also a target feature. If the entirety of the
          feature in the join features is on the boundary of the target feature,
          the feature will not be matched.

          * TOUCHES-The features in the join features will be matched if they
          have a boundary that touches a target feature. When the target and
          join features are lines or polygons, the boundary of the join feature
          can only touch the boundary of the target feature, and no part of the
          join feature can cross the boundary of the target feature.

          * CROSSES-The features in the join features will be matched if a
          target feature is crossed by their outline. The join and target
          features must be lines or polygons. If polygons are used for the join
          or target features, the polygon's boundary (line) will be used. Lines
          that cross at a point will be matched, but lines that share a line
          segment will not.

          * OVERLAPS-The features in the join features will be matched if they
          overlap a target feature.
      spatial_near_distance {Linear Unit}:
          The distance from a target feature within which join features will be
          considered for the spatial join. A search radius is only valid when
          the spatial_relationship parameter value is NEAR or NEAR_GEODESIC.
      temporal_relationship {String}:
          Defines the time criteria used to match features.

          * MEETS-When a target time interval end is equal to the join time
          interval start, the target time meets the join time.

          * MET_BY-When a target time interval start is equal to the join time
          interval end, the target time is met by the join time.

          * OVERLAPS-When a target time interval starts and ends before the
          start and end of the join time interval, the target time overlaps the
          join time.

          * OVERLAPPED_BY-When a target time interval starts and ends after the
          start and end time of the join time interval, the target time is
          overlapped by the join time.

          * DURING-When a target time occurs between the start and end of the
          join time interval, the target time is during the join time.

          * CONTAINS-When a join feature time occurs between the start and end
          of the target time interval, the target time contains the join time.

          * EQUALS-Two times are considered equal if their instants or intervals
          are identical.

          * FINISHES-When a target time ends at the same time as a join time,
          and the target time started after the join time, the target time
          finishes the join time.

          * FINISHED_BY-When a join feature time ends at the same time as a
          target time, and the join time started after the target time, the
          target time is finished by the join time.

          * STARTS-When a target time starts at the same time as the join time
          interval start and ends before the join time interval ends, the target
          time starts the join time.

          * STARTED_BY-When a target interval time starts at the same time as
          the join time and ends after the join time, the target time is started
          by the join time.

          * INTERSECTS-When any part of a target time occurs at the same time as
          the join time, the target time intersects the join time.

          * NEAR-When a target time is within a specified range of time from the
          join time, the target time is near the join time.

          * NEAR_BEFORE-When a target time is before the join time but within a
          specified range of time from the join time, the target time is near
          before the join time. This option is available with ArcGIS Enterprise
          10.6 or later.

          * NEAR_AFTER-When a target time is after the join time but within a
          specified range of time from the join time, the target time is near
          after the join time. This option is available with ArcGIS Enterprise
          10.6 or later.
          Defines the time criteria used to match features.

          * MEETS-When a target time interval end is equal to the join time
          interval start, the target time meets the join time.

          * MET_BY-When a target time interval start is equal to the join time
          interval end, the target time is met by the join time.

          * OVERLAPS-When a target time interval starts and ends before the
          start and end of the join time interval, the target time overlaps the
          join time.

          * OVERLAPPED_BY-When a target time interval starts and ends after the
          start and end time of the join time interval, the target time is
          overlapped by the join time.

          * DURING-When a target time occurs between the start and end of the
          join time interval, the target time is during the join time.

          * CONTAINS-When a join feature time occurs between the start and end
          of the target time interval, the target time contains the join time.

          * EQUALS-Two times are considered equal if their instants or intervals
          are identical.

          * FINISHES-When a target time ends at the same time as a join time,
          and the target time started after the join time, the target time
          finishes the join time.

          * FINISHED_BY-When a join feature time ends at the same time as a
          target time, and the join time started after the target time, the
          target time is finished by the join time.

          * STARTS-When a target time starts at the same time as the join time
          interval start and ends before the join time interval ends, the target
          time starts the join time.

          * STARTED_BY-When a target interval time starts at the same time as
          the join time and ends after the join time, the target time is started
          by the join time.

          * INTERSECTS-When any part of a target time occurs at the same time as
          the join time, the target time intersects the join time.

          * NEAR-When a target time is within a specified range of time from the
          join time, the target time is near the join time.

          * NEAR_BEFORE-When a target time is before the join time but within a
          specified range of time from the join time, the target time is near
          before the join time. This option is available with ArcGIS Enterprise
          10.6 or later.

          * NEAR_AFTER-When a target time is after the join time but within a
          specified range of time from the join time, the target time is near
          after the join time. This option is available with ArcGIS Enterprise
          10.6 or later.
      temporal_near_distance {Time unit}:
          The distance in time from a target feature within which join features
          will be considered for the spatial join. A time is only valid when the
          temporal_relationship parameter value is NEAR, NEAR_BEFORE, or
          NEAR_AFTER and both feature are time enabled.
      attribute_relationship {Value Table}:
          Join features based on values within an attribute field. You must
          specify the attribute field from the target layer that matches an
          attribute field from the join layer.

          * Target Field-An attribute field from the target layer containing
          values to match.

          * Join Field-An attribute field from the join layer containing values
          to match.
      summary_fields {Value Table}:
          The statistics that will be calculated on specified fields.

          * COUNT-Calculates the number of nonnull values. It can be used on
          numeric fields or strings. The count of [null, 0, 2] is 2.

          * SUM-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * MEAN-The mean of numeric values. The mean of [0,2, null] is 1.

          * MIN-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * MAX-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * STDDEV-The standard deviation of a numeric field. The standard
          deviation of [1] is null. The standard deviation of [null, 1,1,1] is
          1.

          * VAR-The variance of a numeric field in a track. The variance of [1]
          is null. The variance of [null, 1,1,1] is 1.

          * RANGE-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * ANY-A sample string from a field of type string.
      join_condition {String}:
          Applies a condition to specified fields. Only features with fields
          that meet these conditions will be joined.For example, you could apply
          a join condition to features in which the
          HealthSpending attribute in the join layer is greater than 20 percent
          of the Income attribute in the target layer. At 10.5 and 10.5.1, the
          join condition to apply this expression is join["HealthSpending"] >
          target["Income"] * .2. At 10.6 and later, use an Arcade expression
          such as $join["HealthSpending"] > $target["Income"] * .2.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.JoinFeatures_geoanalytics(*gp_fixargs((target_layer, join_layer, output_name, join_operation, spatial_relationship, spatial_near_distance, temporal_relationship, temporal_near_distance, attribute_relationship, summary_fields, join_condition, data_store), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ReconstructTracks_geoanalytics', None)
def ReconstructTracks(input_layer=None, output_name=None, track_fields=None, method=None, buffer_type=None, buffer_field=None, buffer_expression=None, time_split=None, summary_fields=None, data_store=None, distance_split=None, time_boundary_split=None, time_boundary_reference=None):
    """ReconstructTracks_geoanalytics(input_layer, output_name, track_fields;track_fields..., method, {buffer_type}, {buffer_field}, {buffer_expression}, {time_split}, {summary_fields;summary_fields...}, {data_store}, {distance_split}, {time_boundary_split}, {time_boundary_reference})

        Creates line or polygon tracks from time-enabled input data.

     INPUTS:
      input_layer (Feature Set):
          The points or polygons to be reconstructed to tracks. The input must
          be a time-enabled layer that represents an instant in time.
      output_name (String):
          The name of the output feature service.
      track_fields (Field):
          One or more fields that will be used to identify unique tracks.
      method (String):
          Specifies the criteria that will be used to reconstruct tracks. If a
          buffer is used, method determines the type of buffer.

          * GEODESIC-If the spatial reference is pannable, tracks will cross
          the date line when appropriate. If the spatial reference is not
          pannable, tracks will be limited to the coordinate system extent and
          may not wrap.

          * PLANAR-The tracks will never cross the date line.
      buffer_type {String}:
          Specifies how the buffer distance will be defined.

          * FIELD-A single field will be used to define the buffer distance.

          * EXPRESSION-An equation using fields and mathematical operators will
          be used to define the buffer distance.
      buffer_field {Field}:
          The  field that will be used to buffer the input features. Field
          values are applied in the units of the spatial reference of the input
          unless you are using a geographic coordinate system, in which case
          they will be in meters.
      buffer_expression {Calculator Expression}:
          The expression that will be used to buffer input features. Fields must
          be numeric, and the expression can include [+ - * / ] operators and
          multiple fields. Calculated values are applied in the units of the
          spatial reference of the input unless you are using a geographic
          coordinate system, in which case they will be in meters. In ArcGIS
          Enterprise 10.5 and 10.5.1, expressions are formatted as
          as_kilometers(distance) * 2 + as_meters(15). In ArcGIS Enterprise 10.6
          or later, use Arcade expressions such as
          as_kilometers($feature.distance) * 2 + as_meters(15).The expression
          that will be used to buffer input features. Fields must
          be numeric, and the expression can include [+ - * / ] operators and
          multiple fields. Calculated values are applied in the units of the
          spatial reference of the input unless you are using a geographic
          coordinate system, in which case they will be in meters. In ArcGIS
          Enterprise 10.5 and 10.5.1, expressions are formatted as
          as_kilometers(distance) * 2 + as_meters(15). In ArcGIS Enterprise 10.6
          or later, use Arcade expressions such as
          as_kilometers($feature.distance) * 2 + as_meters(15).
      time_split {Time unit}:
          Features that are farther apart in time than the time-split duration
          will be split into separate tracks.
      summary_fields {Value Table}:
          The statistics that will be calculated on specified fields.

          * COUNT-Calculates the number of nonnull values. It can be used on
          numeric fields or strings. The count of [null, 0, 2] is 2.

          * SUM-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * MEAN-The mean of numeric values. The mean of [0,2, null] is 1.

          * MIN-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * MAX-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * STDDEV-The standard deviation of a numeric field. The standard
          deviation of [1] is null. The standard deviation of [null, 1,1,1] is
          1.

          * VAR-The variance of a numeric field in a track. The variance of [1]
          is null. The variance of [null, 1,1,1] is 1.

          * RANGE-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * ANY-A sample string from a field of type string.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store.
      distance_split {Linear Unit}:
          Features that are farther apart in distance than the distance split
          value will be split into separate tracks. This parameter is only
          available with ArcGIS Enterprise 10.6 and later.
      time_boundary_split {Time unit}:
          A time span to split your input data into for analysis. A time
          boundary allows your to analyze values within a defined time span. For
          example, if you use a time boundary of 1 day, starting on January 1,
          1980 tracks will be will be split at the beginning of every day. This
          parameter is only available with ArcGIS Enterprise 10.7 and later.
      time_boundary_reference {Date}:
          The reference time used to split your input data into for analysis.
          Time boundaries will be created for the whole span of the data, and
          the reference time does not need to occur at the start. If no
          reference time is used, January 1, 1970 is used. This parameter is
          only available with ArcGIS Enterprise 10.7 and later."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ReconstructTracks_geoanalytics(*gp_fixargs((input_layer, output_name, track_fields, method, buffer_type, buffer_field, buffer_expression, time_split, summary_fields, data_store, distance_split, time_boundary_split, time_boundary_reference), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SummarizeAttributes_geoanalytics', None)
def SummarizeAttributes(input_layer=None, output_name=None, fields=None, summary_fields=None, data_store=None):
    """SummarizeAttributes_geoanalytics(input_layer, output_name, fields;fields..., {summary_fields;summary_fields...}, {data_store})

        Calculates summary statistics for fields in a feature class.

     INPUTS:
      input_layer (Record Set):
          The point, polyline, or polygon layer to be summarized.
      output_name (String):
          The name of the output feature service.
      fields (Field):
          A field or fields used to summarize similar features. For example, if
          you choose a single field called PropertyType with the values of
          commercial and residential, all of the residential fields will be
          summarized together, with summary statistics calculated, and all of
          the commercial fields will be summarized together.
      summary_fields {Value Table}:
          The statistics that will be calculated on specified fields.

          * COUNT-Calculates the number of nonnull values. It can be used on
          numeric fields or strings. The count of [null, 0, 2] is 2.

          * SUM-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * MEAN-The mean of numeric values. The mean of [0,2, null] is 1.

          * MIN-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * MAX-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * STDDEV-The standard deviation of a numeric field. The standard
          deviation of [1] is null. The standard deviation of [null, 1,1,1] is
          1.

          * VAR-The variance of a numeric field in a track. The variance of [1]
          is null. The variance of [null, 1,1,1] is 1.

          * RANGE-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * ANY-A sample string from a field of type string.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SummarizeAttributes_geoanalytics(*gp_fixargs((input_layer, output_name, fields, summary_fields, data_store), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SummarizeWithin_geoanalytics', None)
def SummarizeWithin(summarized_layer=None, output_name=None, polygon_or_bin=None, bin_type=None, bin_size=None, summary_polygons=None, sum_shape=None, shape_units=None, standard_summary_fields=None, weighted_summary_fields=None, data_store=None, group_by_field=None, add_minority_majority=None, add_percentages=None):
    """SummarizeWithin_geoanalytics(summarized_layer, output_name, {polygon_or_bin}, {bin_type}, {bin_size}, {summary_polygons}, {sum_shape}, {shape_units}, {standard_summary_fields;standard_summary_fields...}, {weighted_summary_fields;weighted_summary_fields...}, {data_store}, {group_by_field}, {add_minority_majority}, {add_percentages})

        Overlays a polygon layer with another layer to summarize the number of
        points, length of the lines, or area of the polygons within each
        polygon, and calculates attribute field statistics about those
        features within the polygons.The following are example scenarios using
        Summarize Within:

        * Given watershed boundaries and land-use boundaries by land-use type,
        calculate total acreage of land-use type for each watershed.

        * Given county parcels and city boundaries, summarize the average
        value of vacant parcels within each city boundary.

        * Given counties and roads, summarize the total mileage of roads by
        road type within each county.

     INPUTS:
      summarized_layer (Feature Set):
          The point, line, or polygon features that will be summarized by
          either polygons or bins.
      output_name (String):
          The name of the output polygon feature service containing the
          intersecting geometries and attributes.
      polygon_or_bin {String}:
          Specifies whether summarized_layer will be summarized by polygons or
          bins.

          * POLYGONS-The summarized layer will be aggregated into a polygon
          dataset.

          * BINS-The summarized layer will be aggregated into square or
          hexagonal bins.
      bin_type {String}:
          Specifies the bin shape that will be generated to summarize features.

          * SQUARE-bin_size represents the height of a square. This is the
          default.

          * HEXAGON-bin_size represents the height between two parallel sides.
      bin_size {Linear Unit}:
          The distance interval that represents the bin size and units by which
          the input features will be summarized.
      summary_polygons {Feature Set}:
          The polygons used to summarize the features in the input summarized
          layer.
      sum_shape {Boolean}:
          Specifies whether the length of lines or area of polygons within the
          summary layer (polygon or bin) will be calculated. The count of
          points, lines, and polygons intersecting the summary shape will always
          be included.

          * ADD_SUMMARY-Summary shape values will be calculated. This is the
          default.

          * NO_SUMMARY-Summary shape values will not be calculated.
      shape_units {String}:
          Specifies the unit to be used to calculate shape summary attributes.
          If the input summary_layer is points, no shape unit is necessary,
          since only the count of points within each input polygon is added. If
          the input summary features are lines, specify a linear unit. If the
          input summary features are polygons, specify an areal unit.

          * METERS-Meters

          * KILOMETERS-Kilometers

          * FEET-Feet

          * YARDS-Yards

          * MILES-Miles

          * ACRES-Acres

          * HECTARES-Hectares

          * SQUARE_METERS-Square meters

          * SQUARE_KILOMETERS-Square kilometers

          * SQUARE_FEET-Square feet

          * SQUARE_YARDS-Square yards

          * SQUARE_MILES-Square miles
      standard_summary_fields {Value Table}:
          The statistics that will be calculated on specified fields.

          * COUNT-Calculates the number of nonnull values. It can be used on
          numeric fields or strings. The count of [null, 0, 2] is 2.

          * SUM-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * MEAN-The mean of numeric values. The mean of [0,2, null] is 1.

          * MIN-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * MAX-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * STDDEV-The standard deviation of a numeric field. The standard
          deviation of [1] is null. The standard deviation of [null, 1,1,1] is
          1.

          * VAR-The variance of a numeric field in a track. The variance of [1]
          is null. The variance of [null, 1,1,1] is 1.

          * RANGE-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * ANY-A sample string from a field of type string.
      weighted_summary_fields {Value Table}:
          Specifies the weighted statistics that will be calculated on
          specified fields.

          * COUNT-The count of each field multiplied by the proportion of the
          summarized layer within the polygons.

          * SUM-The sum of weighted values in each field, where the weight
          applied is the proportion of the summarized layer within the polygons.

          * MEAN-The mean of weighted values in each field, where the weight
          applied is the proportion of the summarized layer within the polygons.

          * MIN-The minimum of weighted values in each field, where the weight
          applied is the proportion of the summarized layer within the polygons.

          * MAX-The maximum of weighted values in each field, where the weight
          applied is the proportion of the summarized layer within the polygons.

          * RANGE-The difference between MIN and MAX.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store.
      group_by_field {Field}:
          A field from the input summary features that will be used to calculate
          statistics for each unique attribute value. For example, the input
          summary features contain point locations of businesses that store
          hazardous materials, and one of the fields is HazardClass, containing
          codes that describe the type of hazardous material stored. To
          calculate summaries by each unique value of HazardClass, use it as the
          group by field.
      add_minority_majority {Boolean}:
          Specifies whether minority (least dominant) and majority (most
          dominant) attribute values for each group field within each boundary
          will be added. If they are, two new fields are added to the output
          layer prefixed with Majority_ and Minority_. This parameter only
          applies when using group_by_field.

          * NO_MIN_MAJ-Minority and majority fields will not be added. This is
          the default.

          * ADD_MIN_MAJ-Minority and majority fields will be added.
      add_percentages {Boolean}:
          Specifies whether percentage fields will be added. If they are, the
          percentage of each unique group value is calculated for each input
          polygon. This parameter only applies when using group_by_field.

          * NO_PERCENT-Percentage fields will not be added. This is the default.

          * ADD_PERCENT-Percentage fields will be added."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SummarizeWithin_geoanalytics(*gp_fixargs((summarized_layer, output_name, polygon_or_bin, bin_type, bin_size, summary_polygons, sum_shape, shape_units, standard_summary_fields, weighted_summary_fields, data_store, group_by_field, add_minority_majority, add_percentages), True)))
        return retval
    except Exception as e:
        raise e


# Use Proximity toolset
@gptooldoc('CreateBuffers_geoanalytics', None)
def CreateBuffers(input_layer=None, output_name=None, method=None, buffer_type=None, buffer_field=None, buffer_distance=None, buffer_expression=None, dissolve_option=None, dissolve_fields=None, summary_fields=None, multipart=None, data_store=None):
    """CreateBuffers_geoanalytics(input_layer, output_name, method, buffer_type, {buffer_field}, {buffer_distance}, {buffer_expression}, {dissolve_option}, {dissolve_fields;dissolve_fields...}, {summary_fields;summary_fields...}, {multipart}, {data_store})

        Creates buffers around input features to a specified distance.

     INPUTS:
      input_layer (Feature Set):
          The point, polyline, or polygon features to be buffered.
      output_name (String):
          The name of the output feature service.
      method (String):
          Specifies the method that will be used to create the buffer.

          * GEODESIC-    Buffers are created using a shape-preserving geodesic
          buffer method regardless of the input coordinate system. This is the
          default.

          * PLANAR-      If the input features are in a projected coordinate
          system, Euclidean buffers are created. If the input features are in a
          geographic coordinate system, geodesic buffers are created. The Output
          Coordinate System environment setting can be used to specify a
          coordinate system.
      buffer_type (String):
          Specifies how the buffer distance will be defined.

          * DISTANCE-Apply the same linear distance to all features.

          * FIELD-Select a numeric or string field to represent the buffer
          distance.

          * EXPRESSION-Build an equation using fields, constants, and
          mathematical operations to represent the buffer distance.
      buffer_field {Field}:
          The field that contains the buffer distance for each feature. If a
          field value is a number, it is assumed that the distance is in the
          linear unit of the input_layer spatial reference, unless the
          input_layer is in a geographic coordinate system, in which case, the
          value is assumed to be in meters. If the linear unit specified in the
          field values is invalid or not recognized, the linear unit of the
          input features' spatial reference will be used by default.
      buffer_distance {Linear Unit}:
          The distance around the input features that will be buffered.
          Distance can be expressed in meters, kilometers, feet, yards, miles,
          or nautical miles.
      buffer_expression {Calculator Expression}:
          An equation using fields and mathematical operators that will be
          applied as a buffer to each feature. Fields must be numeric and the
          expression can include [+ - * / ] operators and multiple fields.
          Calculated values are applied in meters unless otherwise specified.
          For example, to apply a buffer that multiples a numeric field named
          distance in kilometers by 2 and adds 15 meters. With ArcGIS Enterprise
          10.5 and 10.5.1 expressions will be formatted
          as the following:as_kilometers(distance) * 2 + as_meters(15). With
          ArcGIS Enterprise 10.6 or later, use Arcade expressions such as
          as_kilometers($feature["distance"]) * 2 + as_meters(15).
      dissolve_option {String}:
          Specifies the dissolve option to remove buffer overlap.

          * NONE-An individual buffer for each feature is maintained regardless
          of overlap. This is the default.

          * ALL-All buffers are dissolved together into a single feature,
          removing any overlap.

          * LIST-Any buffers sharing attribute values in the listed fields
          (carried over from the input features) are dissolved.
      dissolve_fields {Field}:
          A list of one or more fields from the input features on which output
          buffers will be dissolved. Any buffers sharing attribute values in the
          listed fields are dissolved. This option is only required when
          dissolve_option is LIST.
      summary_fields {Value Table}:
          Specifies statistics that can be applied to numeric and string
          fields. If left empty, only count will be calculated. These statistics
          are only applied when dissolve_option is LIST or ALL.

          * COUNT-Calculates the number of nonnull values. It can be used on
          numeric fields or strings. The count of [null, 0, 2] is 2.

          * SUM-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * MEAN-The mean of numeric values. The mean of [0,2, null] is 1.

          * MIN-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * MAX-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * STDDEV-The standard deviation of a numeric field. The standard
          deviation of [1] is null. The standard deviation of [null, 1,1,1] is
          1.

          * VAR-The variance of a numeric field in a track. The variance of [1]
          is null. The variance of [null, 1,1,1] is 1.

          * RANGE-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * ANY-A sample string from a field of type string.
      multipart {Boolean}:
          Specifies whether multipart features will be created.

          * MULTI_PART-Output multipart features will be created where
          appropriate.

          * SINGLE_PART-Instead of creating multipart features, individual
          features will be created for each part. This is the default.
      data_store {String}:
          Specifies the ArcGIS Data Store where the output will be saved. The
          default is SPATIOTEMPORAL_DATA_STORE. All results stored to the
          SPATIOTEMPORAL_DATA_STORE will be stored in WGS84. Results stored in a
          RELATIONAL_DATA_STORE will maintain their coordinate system.

          * SPATIOTEMPORAL_DATA_STORE-Output will be stored in a spatiotemporal
          big data store. This is the default.

          * RELATIONAL_DATA_STORE-Output will be stored in a relational data
          store."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateBuffers_geoanalytics(*gp_fixargs((input_layer, output_name, method, buffer_type, buffer_field, buffer_distance, buffer_expression, dissolve_option, dissolve_fields, summary_fields, multipart, data_store), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject