# COPYRIGHT 2018 ESRI
#
# TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
# Unpublished material - all rights reserved under the
# Copyright Laws of the United States.
#
# For additional information, contact:
# Environmental Systems Research Institute, Inc.
# Attn: Contracts Dept
# 380 New York Street
# Redlands, California, USA 92373
#
# email: contracts@esri.com
import arcgisscripting
import os.path
from ..sa import Raster

__all__ = ["Subset", "Aggregate", "Foreach", "Apply", "Anomaly"]


def Subset(in_raster, variables=None, dimension_definitions=None):
    """Subset(in_raster, {variables}, {dimension_definitions})

    Returns a new raster object that are subseted on the input raster along variables or dimensions or both

    Parameters:
    in_raster(Raster): the multidimensional raster which is to be sliced.
    variables(String or List): a single variable name or a list of variable names to be kept in the output raster. If not specified, all variables will be included
    dimension_definitions(Dict): the dimension interval used to subset the multidimensional raster. This parameter is passed as a dictionary in which the key-value pairs should use one of the formats as follows:
        <dimension_name>:value
        <dimension_name> :(min, max)
        <dimension_name>:[value1, (min1, max1)
        <dimension_name>:(from, to, recurrent_interval_size, recurrent_interval_unit)
    Returns:
        out_raster(Raster) :the output subset multidimensional raster"""

    return arcgisscripting._ia.Slice(in_raster=in_raster, variables=variables,
                                     dimension_definitions=dimension_definitions)


def Aggregate(in_raster, dimension_name, raster_function, raster_function_arguments=None, aggregation_definition=None):
    """Aggregate(in_raster, dimension_name, raster_function, {raster_function_arguments}, {aggregation_definition})

    Aggregate multidimensional raster based on user specified dimension intervals and aggregation method

    Parameters:
    in_raster(Raster):the input multidimensional raster to be aggregated
    dimension_name(String): the aggregation dimension. This is the dimension along which you want to aggregate the variables.
    raster_function(String or File): The name of a raster function, or function chain (in .rft.xml format)
    function_arguments(Dict):The parameter name in the raster function or function chain as the key and their values as the value. If not specified, default values (if existed) would be used
    aggregation_definition(Dict): defines the dimension interval for which the data will be aggregated. The key-value pairs should follow one of the formats below If not specified, all slices along the dimension will be aggregated.
        1.'interval': <interval_keyword>
        use the interval keyword only when the dimension_name is a time dimension. Interval keywords include Hourly, Daily, Weekly, Monthly, Quarterly, Yearly
        2.'interval_value': <v>, 'interval_unit': <u>
        use the interval value and unit when you want to define recurring intervals
        3.'interval_ranges': [(min,max),(min,max), ...]
        user the interval ranges option to define custom intervals for aggregation
    Returns:
    out_raster(Raster): The output aggregated multidimensional raster."""
    raster_function_dict = {
        "MajorityIgnoreNoData": "MajorityContinueOnNoData",
        "MaxIgnoreNoData":"MaxContinueOnNoData",
        "MeanIgnoreNoData":"MeanContinueOnNoData",
        "MedianIgnoreNoData":"MedContinueOnNoData",
        "MinIgnoreNoData":"MinContinueOnNoData",
        "MinorityIgnoreNoData":"MinorityContinueOnNoData",
        "RangeIgnoreNoData":"RangeContinueOnNoData",
        "StdIgnoreNoData": "StdContinueOnNoData",
        "SumIgnoreNoData":"SumContinueOnNoData",
        "VarietyIgnoreNoData":"VarietyContinueOnNoData",
    }
    if raster_function in raster_function_dict.keys():
        raster_function = raster_function_dict[raster_function]

    return arcgisscripting._ia.Aggregate(in_raster=in_raster,
                                         dimension_name=dimension_name,
                                         raster_function=raster_function,
                                         raster_function_arguments=raster_function_arguments,
                                         aggregation_definition=aggregation_definition)


def Foreach(in_raster, raster_function, raster_function_arguments=None):
    """Foreach(in_raster, raster_function, {raster_function_arguments})

    Apply a raster function or a function chain to every slice in the multidimensional raster.

    Parameters:
    in_raster(Raster):the input multidimensional raster dataset
    raster_function(String or File): the name of a raster function, or function chain (in .rft.xml format)
    Function_arguments(Dict):the parameters and values associated with the raster function or function chain. If not specified, default values (if existed) would be used
    Returns:
    out_raster(Raster): The output multidimensional raster"""

    return arcgisscripting._ia.Foreach(in_raster=in_raster,
                                       raster_function=raster_function,
                                       raster_function_arguments=raster_function_arguments)


def Apply(in_raster, raster_function, raster_function_arguments=None):
    """ Apply(in_raster, raster_function, {raster_function_arguments})

    Apply a raster function or function chain to raster(s).

    Parameters:
    in_raster(Raster): The input raster dataset or datasets. The input may include the following:
    1.	a single raster: for raster functions that requrie one raster input.
    2.	(raster1, raster2,...): for raster functions that requrie two or more raster inputs
    3.	[raster1, raster2,...]: for raster functions that require an array of raster inputs
    4.	{<variable_name1>: raster1, <variable_name2>: raster2,...}: for raster functions that require a set of named raster inputs
    raster_function(String or File): The name of a raster function, or function chain (in .rft.xml format)
    function_arguments(Dict):The parameters and values associated with the raster function or function chain. If not specified, default values (if existed) would be used
    Returns:
    out_raster(Raster): The output raster dataset with the function applied."""

    return arcgisscripting._ia.Apply(in_raster=in_raster,
                                     raster_function=raster_function,
                                     raster_function_arguments=raster_function_arguments)


def Anomaly(in_raster, dimension_name='StdTime', anomaly_type='DIFFERENCE_FROM_MEAN', temporal_interval=None,
            ignore_nodata=True):
    """ Anomaly(in_raster, {dimension_name}, {anomaly_type}, {temporal_interval}, {ignore_nodata})

    Calculate the anomaly over time, i.e., how it is different from the mean

    Parameters:
    in_raster(Raster):the raster which the anamaly calculation is performed on
    dimension_name(String): the dimension name which the anomaly definition will be performed along. the default value is 'StdTime'
    anomaly_type(String): method used to calculate anomaly
        1. DIFFERENCE_FROM_MEAN (default): calculate value - mean_value
        2. PERCENT_DIFFERENCE_FROM_MEAN: (value - mean_value)/((value + mean_value)/2)
        3. PERCENT_OF_MEAN: value/mean_value
    temporal_interval: defines the temporal interval including YEARLY, QUARTERLY, MONTHLY, WEEKLY, DAILY, HOURLY. it will calculate an average for each interval and subtract it from the slices within that interval. Default value is None, which means calculating the average using all slices.
    ignore_nodata: default True. The output will be computed by only considering the cells with valid data. Otherwise, if the processing cell location for any of the slices is NoData, then the outputs for that cell on every slice will be NoData. 
    Returns:
    out_raster(Raster): The raster which shows how different each slice in the input raster is different from the mean."""

    # check if anomaly_type has valid inputs
    valid_anomaly_type = ['DIFFERENCE_FROM_MEAN', 'PERCENT_DIFFERENCE_FROM_MEAN', 'PERCENT_OF_MEAN']
    if anomaly_type not in valid_anomaly_type:
        raise ValueError("anomaly_type should be one of %r." % valid_anomaly_type)

    # check if temporal_interval has valid inputs
    valid_temporal_interval = [None, 'YEARLY', 'QUARTERLY', 'MONTHLY', 'WEEKLY', 'DAILY', 'HOURLY']
    if temporal_interval not in valid_temporal_interval:
        raise ValueError("temporal_interval should be one of %r." % valid_temporal_interval)

    # prepare aggregation_definition
    agg_def = None
    if temporal_interval is not None:
        agg_def = {"interval": temporal_interval}

    # check which Mean raster function to use
    rf = "MeanContinueOnNoData"
    if not ignore_nodata:
        rf = "Mean"

    # calcualte average
    agg_output = arcgisscripting._ia.Aggregate(in_raster=in_raster,
                                               dimension_name=dimension_name,
                                               raster_function=rf,
                                               aggregation_definition=agg_def)

    # save aggregation output to avoid repetitive on-the-fly calculations
    agg_output_path = str(agg_output).lower().replace(".afr", "") + ".crf"
    if not os.path.exists(agg_output_path):
        agg_output.save(agg_output_path)  # persist it if not exist

    # load the aggregation output raster
    mean_condition = Raster(agg_output_path, True)

    # calculate anomaly
    if anomaly_type == "PERCENT_DIFFERENCE_FROM_MEAN":
        return (in_raster - mean_condition) / ((in_raster + mean_condition) / 2)
    elif anomaly_type == "PERCENT_OF_MEAN":
        return in_raster / mean_condition
    else:  # anomaly_method = "Difference_From_Mean" default value
        return in_raster - mean_condition
