# -*- coding: utf-8 -*-
#COPYRIGHT 2019 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""The Parcel toolbox contains tools to create, administer and load data
into parcel fabrics."""
__all__ = ['AddParcelType', 'AppendParcels', 'BuildParcelFabric', 'CopyParcels',
           'CreateParcelFabric', 'CreateParcelRecords', 'DisableParcelTopology',
           'EnableParcelTopology', 'ImportParcelFabricPoints',
           'RemoveParcelType', 'UpgradeArcMapParcelFabric',
           'ValidateParcelFabric']
__alias__ = 'parcel'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Tools
@gptooldoc('AppendParcels_parcel', None)
def AppendParcels(in_parcel_fabric=None, target_parcel_fabric=None):
    """AppendParcels_parcel(in_parcel_fabric, target_parcel_fabric)

        Appends parcels from an input parcel fabric to a target parcel
        fabric. If the input parcel fabric is a parcel fabric layer with
        selected polygons, the corresponding parcel features will be appended.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The input parcels that will be appended to the target parcel fabric.
          The input parcel fabric can be from a file geodatabase, an enterprise
          geodatabase or a feature service.
      target_parcel_fabric (Parcel Layer):
          The target parcel fabric to which the parcels will be appended. The
          target parcel fabric can be from a file geodatabase or an enterprise
          geodatabase. On an enterprise geodatabase, parcels are appended to the
          default version."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AppendParcels_parcel(*gp_fixargs((in_parcel_fabric, target_parcel_fabric), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('BuildParcelFabric_parcel', None)
def BuildParcelFabric(in_parcel_fabric=None, extent=None):
    """BuildParcelFabric_parcel(in_parcel_fabric, {extent})

        Builds parcels in a parcel fabric. Parcels can be built from polygons
        or lines. If parcels are built from polygons, the tool creates parcel
        lines and parcel points. If parcels are built from lines, the tool
        creates the missing polygons and points.When building parcels from
        lines, parcel seeds are required.Learn more about building parcels
        from polygons and lines.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The parcel fabric for which to build parcels. The parcel fabric can
          be from a file geodatabase or a feature service.
      extent {Extent}:
          The extent of the dataset to be processed. Only features that fall
          within the specified extent will be processed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.BuildParcelFabric_parcel(*gp_fixargs((in_parcel_fabric, extent), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CopyParcels_parcel', None)
def CopyParcels(in_parcel_fabric=None, target_database=None, out_dataset_name=None, out_fabric_name=None):
    """CopyParcels_parcel(in_parcel_fabric, target_database, {out_dataset_name}, {out_fabric_name})

        Copies parcels from an input parcel fabric to a new parcel fabric in
        a new feature dataset.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The input parcels that will be copied to a new parcel fabric. The
          input parcel fabric can be from a file geodatabase, from an enterprise
          geodatabase connection, or from a feature service.
      target_database (Workspace):
          The geodatabase in which the new parcel fabric will be created. The
          geodatabase can be a file or enterprise geodatabase.
      out_dataset_name {String}:
          The name of the feature dataset that will be created for the new
          parcel fabric.
      out_fabric_name {String}:
          The name of the new parcel fabric."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CopyParcels_parcel(*gp_fixargs((in_parcel_fabric, target_database, out_dataset_name, out_fabric_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportParcelFabricPoints_parcel', None)
def ImportParcelFabricPoints(source_points=None, target_parcel_fabric=None, match_point_method=None, search_distance=None, update_type=None, record_name=None, match_field=None, conflicts_table=None):
    """ImportParcelFabricPoints_parcel(source_points, target_parcel_fabric, match_point_method, search_distance, update_type, {record_name}, {match_field}, {conflicts_table})

        Imports point data from a source point feature class into the parcel
        fabric points feature class. Parcel fabric points that match or lie
        within a proximity tolerance of the source points will be updated with
        the imported point data. If the source points layer has a selection,
        only the selected point information will be imported. Parcel fabric
        points can be updated in the following ways:

        * Points can be retired and new points can be created with updated
        information from the imported points.

        *  Points can be updated with attribute information from the source
        points. The existing parcel fabric points still remain active
        (nonhistoric).
        If the geometry (x,y,z coordinates) of the parcel fabric points is
        updated (both new and existing), connected parcel lines and polygons
        will be updated to match the new coordinate locations.When new points
        are created, they can be optionally assigned to a new
        or existing parcel record.

     INPUTS:
      source_points (Feature Layer):
          The source point feature class that will be used to update points in
          the target parcel fabric.
      target_parcel_fabric (Parcel Layer):
          The target parcel fabric containing the points that will be updated.
          The target parcel fabric can be from a file geodatabase, an enterprise
          geodatabase connected to the default version, or a feature service.
      match_point_method (String):
          The name of the record that will be associated with the new, imported
          points.If the record already exists in the target parcel fabric, the
          new
          points are associated with the record. If the record does not exist, a
          record will be created. If new points replace existing points, and
          Update Type is set to Retire and replace (update_type =
          RETIRE_AND_REPLACE in Python), the record will be used to retire the
          points as historic.
      search_distance (Linear Unit):
          Specifies the method that will be used to find parcel fabric points
          that match the source points.

          * PROXIMITY-Parcel fabric points that lie within the proximity
          tolerance of the source points will be matched to the source points
          and updated. This is the default.

          * NAME_AND_PROXIMITY-          Parcel fabric points that lie within
          the proximity tolerance and have the same name as the source points
          will be matched to the source points and updated.

          * GLOBALID_AND_PROXIMITY-Parcel fabric points that lie within the
          proximity tolerance and have the same Global ID as the source points
          will be matched to the source points and updated. Global IDs are
          stored in the Global ID field on the parcel fabric points feature
          class and in the specified Global ID field of the source feature
          class.
      update_type (String):
          The field that will be used to match source points to parcel fabric
          points when Name and proximity (NAME_AND_PROXIMITY in Python) or
          Global ID and proximity (GLOBALID_AND_PROXIMITY in Python) is used for
          the Match Point Method (match_point_method in Python) parameter. When
          searching by name, the field in the source point feature class should
          be of type Text. When searching by Global ID, the field in the source
          point feature class should be of type GUID.
      record_name {String}:
          The distance that will be used to search for parcel fabric points
          that lie within the proximity of source points. If a parcel fabric
          point is found within the search distance of a source point, the
          points will be matched and the parcel fabric point will be updated.
      match_field {Field}:
          Specifies the type of update that will be applied to parcel fabric
          points that match source points.

          * ALL-The geometry (x,y,z) and matching attribute fields of parcel
          fabric points will be updated. If the geometry of parcel fabric points
          are updated, coincident parcel features are updated as well. This is
          the default.

          * GEOMETRY_XYZ-                Only the geometry (x,y,z) of the
          parcel fabric points will be updated. Coincident parcel features will
          be updated as well.

          * RETIRE_AND_REPLACE-Source points will be imported as new parcel
          fabric points. Any matching parcel fabric points will be retired as
          historic. The Retired By Record field of each matching parcel fabric
          points will be populated with the GlobalID of the record specified in
          the Record Name parameter.

     OUTPUTS:
      conflicts_table {Table}:
          The path and name of the output table that will store conflicts. If
          more than one parcel fabric point is found within the search tolerance
          of a source point, the object IDs of the source points and parcel
          fabric points will be reported in the conflicts table."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportParcelFabricPoints_parcel(*gp_fixargs((source_points, target_parcel_fabric, match_point_method, search_distance, update_type, record_name, match_field, conflicts_table), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ValidateParcelFabric_parcel', None)
def ValidateParcelFabric(in_parcel_fabric=None, extent=None):
    """ValidateParcelFabric_parcel(in_parcel_fabric, {extent})

        Validates a parcel fabric against a predefined set of parcel rules,
        geodatabase topology rules, and any additional rules you have added
        for your organization.The parcel fabric uses geodatabase topology
        rules and parcel rules to
        define parcels and model their behavior. Geodatabase topology rules
        define the spatial relationships between parcel features, and parcel
        rules define behavior that is specific to parcel features. You can
        define additional geodatabase topology rules and attribute rules to
        manage and enforce data quality standards in your organization.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The parcel fabric to be validated. The parcel fabric can be from a
          file geodatabase or a feature service.
      extent {Extent}:
          The extent of the dataset to be processed. Only features that fall
          within the specified extent will be processed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ValidateParcelFabric_parcel(*gp_fixargs((in_parcel_fabric, extent), True)))
        return retval
    except Exception as e:
        raise e


# Administration toolset
@gptooldoc('AddParcelType_parcel', None)
def AddParcelType(in_parcel_fabric=None, name=None):
    """AddParcelType_parcel(in_parcel_fabric, name)

        Adds a parcel type to a parcel fabric. A parcel type is defined by a
        separate polygon and line feature class. Parcel type feature classes
        are controlled by the parcel fabric dataset.Parcels are added to the
        parcel fabric as parcel types. Examples of
        parcel types are ownership parcels, administrative parcels, and
        subdivision parcels.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The parcel fabric to which the parcel type will be added. The parcel
          fabric can be from a file or and enterprise geodatabase.
      name (String):
          The name of the parcel type. The name will be assigned to the output
          polygon and line feature classes."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddParcelType_parcel(*gp_fixargs((in_parcel_fabric, name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateParcelFabric_parcel', None)
def CreateParcelFabric(target_dataset=None, name=None):
    """CreateParcelFabric_parcel(target_dataset, name)

        Creates a parcel fabric and its associated datasets. The parcel
        fabric is created in a feature dataset that resides in a file or an
        enterprise geodatabase.The parcel fabric is created as a controller
        dataset that controls the
        following datasets:

        * Parcel fabric topology

        * Records feature class

        * Connections feature class

        * Points feature class
        Parcels are added to the parcel fabric as parcel types. Use the Add
        Parcel Type tool to add parcel types to the parcel fabric. The
        Connections, Points and parcel type feature classes participate in the
        parcel fabric topology.

     INPUTS:
      target_dataset (Feature Dataset):
          The feature dataset in which the parcel fabric and related schema
          will be created. The feature dataset can reside in a file or an
          enterprise geodatabase.
      name (String):
          The name of the parcel fabric that will be created. Associated
          datasets will be prefixed with the parcel fabric name."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateParcelFabric_parcel(*gp_fixargs((target_dataset, name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateParcelRecords_parcel', None)
def CreateParcelRecords(in_parcel_features=None, record_field=None):
    """CreateParcelRecords_parcel(in_parcel_features, record_field)

        Creates parcel records for the input parcel fabric features using a
        record name field. Parcel records are created and added to the parcel
        fabric Records feature class. The parcel record polygons will match
        the cumulative geometry of all parcel polygons associated with them.
        The Records feature class stores information about the legal parcel
        record such as the record date and record type. In the parcel fabric,
        parcel features are associated with the record that created and
        retired them (made historic).

     INPUTS:
      in_parcel_features (Feature Layer):
          The input parcel features that will be used to create parcel
          records.The input parcel features can be from a parcel fabric in a
          file
          geodatabase or an enterprise geodatabase.
      record_field (Field):
          The attribute field that will be used to create parcel records. The
          attribute field must be a text field and must be populated with parcel
          record names."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateParcelRecords_parcel(*gp_fixargs((in_parcel_features, record_field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DisableParcelTopology_parcel', None)
def DisableParcelTopology(in_parcel_fabric=None):
    """DisableParcelTopology_parcel(in_parcel_fabric)

        Disables topology on a parcel fabric. System-defined parcel rules and
        topology rules and parcel fabric feature classes will be removed from
        the topology.Disable the parcel fabric topology before operations such
        as adding
        parcel types, adding attribute fields, and batch calculating attribute
        fields.Learn more about the parcel fabric topology.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The parcel fabric for which the topology will be disabled. The input
          parcel fabric can be from a file geodatabase or an enterprise
          geodatabase."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DisableParcelTopology_parcel(*gp_fixargs((in_parcel_fabric,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('EnableParcelTopology_parcel', None)
def EnableParcelTopology(in_parcel_fabric=None):
    """EnableParcelTopology_parcel(in_parcel_fabric)

        Enables topology on a parcel fabric.The tool adds the following to
        the parcel topology:

        * System-defined parcel rules and geodatabase topology rules

        * Parcel fabric feature classes
        Once the parcel fabric topology is enabled, the parcel fabric can be
        validated to identify rule errors, and parcels can be built.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The parcel fabric for which the topology will be enabled. The input
          parcel fabric can be from a file geodatabase or an enterprise
          geodatabase."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.EnableParcelTopology_parcel(*gp_fixargs((in_parcel_fabric,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RemoveParcelType_parcel', None)
def RemoveParcelType(in_parcel_fabric=None, name=None):
    """RemoveParcelType_parcel(in_parcel_fabric, name)

        Removes a parcel type from a parcel fabric.

     INPUTS:
      in_parcel_fabric (Parcel Layer):
          The parcel fabric from which the parcel type will be removed. The
          parcel fabric can be from a file geodatabase or an enterprise
          geodatabase.
      name (String):
          The name of the parcel type."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RemoveParcelType_parcel(*gp_fixargs((in_parcel_fabric, name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpgradeArcMapParcelFabric_parcel', None)
def UpgradeArcMapParcelFabric(in_parcel_fabric=None, target_dataset=None, name=None):
    """UpgradeArcMapParcelFabric_parcel(in_parcel_fabric, target_dataset, name)

        Upgrades an ArcMap parcel fabric to an ArcGIS Pro parcel fabric.The
        tool creates a parcel fabric in a feature dataset and transfers
        data from the ArcMap parcel fabric feature classes to the ArcGIS Pro
        parcel fabric feature classes. The existing ArcMap parcel fabric is
        not altered.

     INPUTS:
      in_parcel_fabric (Parcel Fabric Layer for ArcMap):
          The ArcMap parcel fabric that will be upgraded to an ArcGIS Pro
          parcel fabric.
      target_dataset (Feature Dataset):
          The feature dataset that will contain the upgraded ArcGIS Pro parcel
          fabric.
      name (String):
          The name of the upgraded ArcGIS Pro parcel fabric."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpgradeArcMapParcelFabric_parcel(*gp_fixargs((in_parcel_fabric, target_dataset, name), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject